@@ -4,11 +4,13 @@
 # See top-level LICENSE file for more information
 
 
-def test_svn_loader(mocker, swh_app, celery_session_worker, swh_config):
+def test_svn_loader(
+    mocker, swh_scheduler_celery_app, swh_scheduler_celery_worker, swh_config
+):
     mock_loader = mocker.patch("swh.loader.svn.loader.SvnLoader.load")
     mock_loader.return_value = {"status": "eventful"}
 
-    res = swh_app.send_task(
+    res = swh_scheduler_celery_app.send_task(
         "swh.loader.svn.tasks.LoadSvnRepository",
         kwargs=dict(url="some-technical-url", origin_url="origin-url"),
     )
@@ -19,11 +21,13 @@ def test_svn_loader(mocker, swh_app, celery_session_worker, swh_config):
     assert res.result == {"status": "eventful"}
 
 
-def test_svn_loader_from_dump(mocker, swh_app, celery_session_worker, swh_config):
+def test_svn_loader_from_dump(
+    mocker, swh_scheduler_celery_app, swh_scheduler_celery_worker, swh_config
+):
     mock_loader = mocker.patch("swh.loader.svn.loader.SvnLoaderFromDumpArchive.load")
     mock_loader.return_value = {"status": "eventful"}
 
-    res = swh_app.send_task(
+    res = swh_scheduler_celery_app.send_task(
         "swh.loader.svn.tasks.MountAndLoadSvnRepository",
         kwargs=dict(url="some-url", archive_path="some-path"),
     )
@@ -35,12 +39,12 @@ def test_svn_loader_from_dump(mocker, swh_app, celery_session_worker, swh_config
 
 
 def test_svn_loader_from_remote_dump(
-    mocker, swh_app, celery_session_worker, swh_config
+    mocker, swh_scheduler_celery_app, swh_scheduler_celery_worker, swh_config
 ):
     mock_loader = mocker.patch("swh.loader.svn.loader.SvnLoaderFromRemoteDump.load")
     mock_loader.return_value = {"status": "eventful"}
 
-    res = swh_app.send_task(
+    res = swh_scheduler_celery_app.send_task(
         "swh.loader.svn.tasks.DumpMountAndLoadSvnRepository",
         kwargs=dict(url="some-remote-dump-url", origin_url="origin-url"),
     )
